@@ -36,7 +36,7 @@ my $LOCK    = File::Spec->catfile($FindBin::Bin, 'pc_files.lock');
     $_;
 } @PC_PATHS;
     
-print Dumper(\@PC_PATHS);
+note Dumper(\@PC_PATHS);
 
 $ENV{PKG_CONFIG_PATH} = join($Config{path_sep}, @PC_PATHS);
 
@@ -130,7 +130,7 @@ sub _single_flags_test {
             
             #these files define $prefix, but don't actually use them for
             #flags:
-            if($base =~ /^(?:glu?)$/) {
+            if($base =~ /^(?:glu?|libconfig)$/) {
                 note "Skipping gl pcfiles which define but do not use 'prefix'";
                 return;
             }
